'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var PASSIVE_EVENT_LISTENERS = ['touchstart'];
var matches = function (prototype) {
  return ['webkitMatchesSelector', 'msMatchesSelector', 'matches'].filter(function (property) {
    return property in prototype;
  }).slice(-1)[0];
}(HTMLElement.prototype);

exports.default = function () {
  var classNames = [];
  var cssVariables = {};

  return {
    addClass: function addClass(updateClassNames) {
      return function (className) {
        classNames = [].concat(_toConsumableArray(classNames), [className]);
        updateClassNames(classNames);
      };
    },
    computeBoundingRect: function computeBoundingRect(element) {
      return function () {
        var _element$getBoundingC = element.getBoundingClientRect(),
            bottom = _element$getBoundingC.bottom,
            left = _element$getBoundingC.left,
            right = _element$getBoundingC.right,
            top = _element$getBoundingC.top;

        return { top: top, left: left, right: right, bottom: bottom, width: right - left, height: bottom - top };
      };
    },
    deregisterInteractionHandler: function deregisterInteractionHandler(element) {
      return function (type, handler) {
        return element.removeEventListener(type, handler);
      };
    },
    isSurfaceActive: function isSurfaceActive(element) {
      return function () {
        return element[matches](':active');
      };
    },
    isSurfaceDisabled: function isSurfaceDisabled(disabled) {
      return function () {
        return disabled;
      };
    },
    isUnbounded: function isUnbounded(centered) {
      return function () {
        return centered;
      };
    },
    registerInteractionHandler: function registerInteractionHandler(element) {
      return function (type, handler) {
        return element.addEventListener(type, handler, PASSIVE_EVENT_LISTENERS.includes(type) ? { passive: true } : null);
      };
    },
    removeClass: function removeClass(updateClassNames) {
      return function (className) {
        classNames = classNames.filter(function (currentClassName) {
          return currentClassName !== className;
        });
        updateClassNames(classNames);
      };
    },
    updateCssVariable: function updateCssVariable(updateCssVariables) {
      return function (variable, value) {
        cssVariables = _extends({}, cssVariables, _defineProperty({}, variable, value));
        updateCssVariables(cssVariables);
      };
    }
  };
};